@@ -59,85 +59,25 @@ struct _vte_draw_text_request {
 	gshort x, y, columns;
 };
 
-struct _vte_draw_impl {
-	const char *name;
-	gboolean (*check)(struct _vte_draw *draw, GtkWidget *widget);
-	void (*create)(struct _vte_draw *draw, GtkWidget *widget);
-	void (*destroy)(struct _vte_draw *draw);
-	GdkVisual* (*get_visual)(struct _vte_draw *draw);
-	GdkColormap* (*get_colormap)(struct _vte_draw *draw);
-	void (*start)(struct _vte_draw *draw);
-	void (*end)(struct _vte_draw *draw);
-	void (*set_background_solid)(struct _vte_draw *,
-				     GdkColor *color,
-				     guint16 opacity);
-	void (*set_background_image)(struct _vte_draw *,
-				     enum VteBgSourceType type,
-				     GdkPixbuf *pixbuf,
-				     const char *file,
-				     const GdkColor *color,
-				     double saturation);
-	void (*set_background_scroll)(struct _vte_draw *,
-				      gint, gint);
-	void (*clip)(struct _vte_draw *, GdkRegion *);
-	gboolean always_requires_clear;
-	void (*clear)(struct _vte_draw *, gint, gint, gint, gint);
-	void (*set_text_font)(struct _vte_draw *,
-			      const PangoFontDescription *,
-			      VteTerminalAntiAlias);
-	void (*get_text_metrics)(struct _vte_draw *, gint *, gint *, gint *);
-	int (*get_char_width)(struct _vte_draw *, vteunistr c, int columns,
-			      gboolean);
-	gboolean (*has_bold)(struct _vte_draw *);
-	void (*draw_text)(struct _vte_draw *,
-			  		  struct _vte_draw_text_request *, gsize,
-					  GdkColor *, guchar, gboolean);
-	gboolean (*has_char)(struct _vte_draw *, vteunistr, gboolean);
-	void (*draw_rectangle)(struct _vte_draw *,
-			       gint, gint, gint, gint,
-			       GdkColor *, guchar);
-	void (*fill_rectangle)(struct _vte_draw *,
-			       gint, gint, gint, gint,
-			       GdkColor *, guchar);
-};
-
-struct _vte_draw {
-	GtkWidget *widget;
-
-	gboolean started;
-
-	gboolean requires_clear;
-
-	const struct _vte_draw_impl *impl;
-
-	/* for use by impl */
-	gpointer impl_data;
-};
-
 /* Create and destroy a draw structure. */
 struct _vte_draw *_vte_draw_new(GtkWidget *widget);
 void _vte_draw_free(struct _vte_draw *draw);
 
-/* Get the visual and colormap the draw structure desires.  Certain draw
-   implementations may require that this visual/colormap pair be used when
-   creating a window, and may fail otherwise. */
-GdkVisual *_vte_draw_get_visual(struct _vte_draw *draw);
-GdkColormap *_vte_draw_get_colormap(struct _vte_draw *draw,
-				    gboolean maybe_use_default);
-
 /* Begin and end a drawing operation.  If anything is buffered locally, it is
    flushed to the window system when _end() is called. */
 void _vte_draw_start(struct _vte_draw *draw);
 void _vte_draw_end(struct _vte_draw *draw);
 
 void _vte_draw_set_background_solid(struct _vte_draw *draw,
-				    GdkColor *color,
-				    guint16 opacity);
+				    double red,
+				    double green,
+				    double blue,
+				    double opacity);
 void _vte_draw_set_background_image(struct _vte_draw *draw,
-				    enum VteBgSourceType type,
+				    VteBgSourceType type,
 				    GdkPixbuf *pixbuf,
 				    const char *file,
-				    const GdkColor *color,
+				    const PangoColor *color,
 				    double saturation);
 void _vte_draw_set_background_scroll(struct _vte_draw *draw,
 				     gint x, gint y);
@@ -157,19 +97,19 @@ int _vte_draw_get_char_width(struct _vte_draw *draw, vteunistr c, int columns,
 
 void _vte_draw_text(struct _vte_draw *draw,
 		    struct _vte_draw_text_request *requests, gsize n_requests,
-		    GdkColor *color, guchar alpha, gboolean);
+		    const PangoColor *color, guchar alpha, gboolean);
 gboolean _vte_draw_char(struct _vte_draw *draw,
 			struct _vte_draw_text_request *request,
-			GdkColor *color, guchar alpha, gboolean bold);
+			const PangoColor *color, guchar alpha, gboolean bold);
 gboolean _vte_draw_has_char(struct _vte_draw *draw, vteunistr c, gboolean bold);
 
 
 void _vte_draw_fill_rectangle(struct _vte_draw *draw,
 			      gint x, gint y, gint width, gint height,
-			      GdkColor *color, guchar alpha);
+			      const PangoColor *color, guchar alpha);
 void _vte_draw_draw_rectangle(struct _vte_draw *draw,
 			      gint x, gint y, gint width, gint height,
-			      GdkColor *color, guchar alpha);
+			      const PangoColor *color, guchar alpha);
 
 G_END_DECLS
 
