@@ -719,6 +719,11 @@ vte_sequence_handler_decset_internal(VteTerminal *terminal,
 		 GINT_TO_POINTER(FALSE),
 		 GINT_TO_POINTER(TRUE),
 		 NULL, NULL},
+		/* 2004: Bracketed paste mode. */
+		{2004, &terminal->pvt->screen->bracketed_paste_mode, NULL, NULL,
+		 GINT_TO_POINTER(FALSE),
+		 GINT_TO_POINTER(TRUE),
+		 NULL, NULL,},
 	};
 
 	/* Handle the setting. */
